﻿using StockSharp.Algo;
using StockSharp.Algo.Candles;
using StockSharp.Algo.Strategies;
using StockSharp.Algo.Testing;
using StockSharp.BusinessEntities;
using StockSharp.Logging;
using System;

namespace HistoryTest
{
    class SmaStrategy : Strategy
    {
        private Subscription _series;

        public SmaStrategy(CandleSeries series)
        {
            _series = new Subscription(series);
        }

        protected override void OnStarted()
        {
            this
                .WhenCandlesFinished(_series.CandleSeries)
                .Do(ProcessCandle)
                .Apply(this);

            this.Security.WhenMarketDepthChanged(Connector).Do(ProcessMarketDepth).Apply(this);

            Subscribe(_series);

            base.OnStarted();
        }

        private void ProcessMarketDepth(MarketDepth marketDepth)
        {
            Console.BackgroundColor = ConsoleColor.Red;
            Console.WriteLine($"{marketDepth.LastChangeTime} {marketDepth}");
        }

        private void ProcessCandle(Candle candle)
        {
            Console.BackgroundColor = ConsoleColor.Green;
            Console.WriteLine($"{candle.OpenTime} {candle.OpenPrice} {candle.HighPrice} {candle.LowPrice} {candle.ClosePrice} {candle.TotalVolume} {candle.Security}");
        }
    }
}